.center { 
  text-align: center;
}

.center table { 
  margin-left: auto;
  margin-right: auto;
  text-align: center;
}

body {
  font-family: verdana, sans-serif;
  background: #333333;
  color: #DDDDDD;
}

a:link {
  color: #95DDFF;
  background: transparent;
}

a:visited {
  color: #AAAAAA;
  background: transparent;
}

a:hover {
  color: #BBDDFF;
  background: #555555;
}

.small {
  font-size: 75%;
}

.large {
  font-size: 200%;
}

.tiled {
  background-image: url(".tile.png");
  background-repeat: repeat-x;
  background-color: #000000;
  padding: 0;
}

.thumb {
  background-color: #000000;
  text-align: center;
  vertical-align: middle;
}

.slide {
  background-color: #ffffff;
  text-align: center;
  vertical-align: middle;
}
